# Changelog

All notable changes to this project will be documented in this file.

## Unreleased

Initial robot description.

### Added

- Mesh files for the legs, wheel tire and mjbots parts
- ROS build and package files
- Robot description (kinematics, inertias, collisions) in URDF
- Scripts to compute box and cylinder inertias
